==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/item/enchantment/SetItemCooldownEnchantmentEffect.java <==
package com.github.thedeathlycow.frostiful.item.enchantment;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_5699;
import net.minecraft.class_7923;
import net.minecraft.class_9699;
import net.minecraft.class_9721;

public record SetItemCooldownEnchantmentEffect(
        class_1792 item,
        int durationTicks
) implements class_9721 {

    public static final MapCodec<SetItemCooldownEnchantmentEffect> CODEC = RecordCodecBuilder.mapCodec(
            instance -> instance.group(
                    class_7923.field_41178.method_39673()
                            .fieldOf("item")
                            .forGetter(SetItemCooldownEnchantmentEffect::item),
                    class_5699.field_33441
                            .fieldOf("duration_ticks")
                            .forGetter(SetItemCooldownEnchantmentEffect::durationTicks)
            ).apply(instance, SetItemCooldownEnchantmentEffect::new)
    );

    @Override
    public void method_60220(class_3218 world, int level, class_9699 context, class_1297 user, class_243 pos) {
        if (context.comp_2684() instanceof class_1657 player) {
            player.method_7357().method_7906(this.item, this.durationTicks);
        }
    }

    @Override
    public MapCodec<? extends class_9721> method_60219() {
        return CODEC;
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/item/enchantment/SetItemCooldownEnchantmentEffect.java <==
package com.github.thedeathlycow.frostiful.item.enchantment;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_5699;
import net.minecraft.class_7923;
import net.minecraft.class_9699;
import net.minecraft.class_9721;

public record SetItemCooldownEnchantmentEffect(
        class_1792 item,
        int durationTicks
) implements class_9721 {

    public static final MapCodec<SetItemCooldownEnchantmentEffect> CODEC = RecordCodecBuilder.mapCodec(
            instance -> instance.group(
                    class_7923.field_41178.method_39673()
                            .fieldOf("item")
                            .forGetter(SetItemCooldownEnchantmentEffect::item),
                    class_5699.field_33441
                            .fieldOf("duration_ticks")
                            .forGetter(SetItemCooldownEnchantmentEffect::durationTicks)
            ).apply(instance, SetItemCooldownEnchantmentEffect::new)
    );

    @Override
    public void method_60220(class_3218 world, int level, class_9699 context, class_1297 user, class_243 pos) {
        if (context.comp_2684() instanceof class_1657 player) {
            player.method_7357().method_62835(context.comp_2682(), this.durationTicks);
        }
    }

    @Override
    public MapCodec<? extends class_9721> method_60219() {
        return CODEC;
    }
}
